@@ -66,6 +66,19 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
         子频道所属的频道。
     id: :class:`int`
         子频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     category_id: Optional[:class:`int`]
         这个子频道属于的分类频道，如果没有则返回 ``None`` 。
     position: :class:`int`
@@ -83,7 +96,8 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
         'category_id',
         'position',
         '_type',
-        'last_message_id'
+        'last_message_id',
+        'private_type'
     )
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: TextChannelPayload):
@@ -109,6 +123,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
         self._type: int = data.get('type', self._type)
+        self.private_type: int = data.get('private_type')
 
     async def _get_channel(self):
         return self
@@ -174,6 +189,19 @@ class VoiceChannel(abc.GuildChannel, Hashable):
         子频道所属的频道。
     id: :class:`int`
         频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     position: :class:`int`
         在类别列表中的位置。 这是一个从 0 开始的数字。例如顶部频道是位置 0。
     """
@@ -184,6 +212,7 @@ class VoiceChannel(abc.GuildChannel, Hashable):
         '_state',
         'position',
         'category_id',
+        'private_type'
     )
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: VoiceChannelPayload):
@@ -196,6 +225,7 @@ class VoiceChannel(abc.GuildChannel, Hashable):
         self.name: str = data['name']
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
+        self.private_type: int = data.get('private_type')
 
     def __repr__(self) -> str:
         attrs = [
@@ -237,6 +267,19 @@ class LiveChannel(abc.GuildChannel, Hashable, abc.Messageable):
         子频道所属的频道。
     id: :class:`int`
         频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     position: :class:`int`
         在类别列表中的位置。 这是一个从 0 开始的数字。例如顶部频道是位置 0。
     """
@@ -248,6 +291,7 @@ class LiveChannel(abc.GuildChannel, Hashable, abc.Messageable):
         '_state',
         'position',
         'category_id',
+        'private_type'
     )
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: LiveChannelPayload):
@@ -260,6 +304,7 @@ class LiveChannel(abc.GuildChannel, Hashable, abc.Messageable):
         self.name: str = data['name']
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
+        self.private_type: int = data.get('private_type')
 
     def __repr__(self) -> str:
         attrs = [
@@ -301,6 +346,19 @@ class AppChannel(abc.GuildChannel, Hashable):
         子频道所属的频道。
     id: :class:`int`
         频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     position: :class:`int`
         在类别列表中的位置。 这是一个从 0 开始的数字。例如顶部频道是位置 0。
     """
@@ -311,6 +369,7 @@ class AppChannel(abc.GuildChannel, Hashable):
         '_state',
         'position',
         'category_id',
+        'private_type'
     )
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: AppChannelPayload):
@@ -323,6 +382,7 @@ class AppChannel(abc.GuildChannel, Hashable):
         self.name: str = data['name']
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
+        self.private_type: int = data.get('private_type')
 
     def __repr__(self) -> str:
         attrs = [
@@ -364,6 +424,19 @@ class ThreadChannel(abc.GuildChannel, Hashable):
         子频道所属的频道。
     id: :class:`int`
         频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     position: :class:`int`
         在类别列表中的位置。 这是一个从 0 开始的数字。例如顶部频道是位置 0。
     """
@@ -374,6 +447,7 @@ class ThreadChannel(abc.GuildChannel, Hashable):
         '_state',
         'position',
         'category_id',
+        'private_type'
     )
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: ThreadChannelPayload):
@@ -386,6 +460,7 @@ class ThreadChannel(abc.GuildChannel, Hashable):
         self.name: str = data['name']
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
+        self.private_type: int = data.get('private_type')
 
     def __repr__(self) -> str:
         attrs = [
@@ -428,11 +503,24 @@ class CategoryChannel(abc.GuildChannel, Hashable):
         类别所属的公会。
     id: :class:`int`
         类别频道 ID。
+    private_type: :class:`int`
+        子频道私密类型。
+
+        +----+---------------------+
+        | 值 | 含义                |
+        +----+---------------------+
+        | 0  | 公开频道            |
+        +----+---------------------+
+        | 1  | 群主管理员可见      |
+        +----+---------------------+
+        | 2  | 群主管理员+指定成员 |
+        +----+---------------------+
+
     position: :class:`int`
         在类别列表中的位置。 这是一个从 0 开始的数字。例如顶部频道是位置 0。
     """
 
-    __slots__ = ('name', 'id', 'guild', '_state', 'position', 'category_id')
+    __slots__ = ('name', 'id', 'guild', '_state', 'position', 'category_id', 'private_type')
 
     def __init__(self, *, state: ConnectionState, guild: Guild, data: CategoryChannelPayload):
         self._state: ConnectionState = state
@@ -447,6 +535,7 @@ class CategoryChannel(abc.GuildChannel, Hashable):
         self.name: str = data['name']
         self.category_id: Optional[int] = int(data.get('parent_id'))
         self.position: int = data['position']
+        self.private_type: int = data.get('private_type')
 
     @property
     def _sorting_bucket(self) -> int:
